@@ -21,6 +21,7 @@ Usage:
     srm [options] group list
     srm [options] group delete           <group-name>
     srm [options] group create           <group-name> [<datastore-name>...]
+    srm [options] purge
 
 Options:
     -h --help                   show this screen.
@@ -43,7 +44,7 @@ import colorama
 import sys
 import docopt
 from infi.traceback import pretty_traceback_and_exit_decorator
-from client import SrmClient, InternalSrmClient, SrmClientException
+from .client import SrmClient, InternalSrmClient, SrmClientException
 from infi.pyutils.contexts import contextmanager
 from tabulate import tabulate
 import re
@@ -176,7 +177,7 @@ def do_disable_pair(arguments):
 
 def do_delete_protection_group(arguments):
     with _internal_open(arguments) as client:
-        [group] = [item for item in client.get_protection_groups() if item['name'] == arguments['<group-name>']]
+        [group] = [item for item in client.get_protection_groups() if item['name'] == arguments['<group-name>'][0]]
         client.delete_protection_group(group)
 
 
@@ -186,7 +187,7 @@ def do_create_protection_group(arguments):
         datastores = [item for item in client.get_unprotected_datastores() if item['name'] in datastore_names]
         assert len(datastore_names) == len(datastores)
         assert len({item['pair'] for item in datastores}) == 1
-        client.create_protection_group(arguments['<group-name>'], datastores)
+        client.create_protection_group(arguments['<group-name>'][0], datastores)
 
 
 def do_delete_recovery_plan(arguments):
@@ -207,14 +208,14 @@ def do_create_array(arguments):
                      item['name'] == arguments['<array-type>']]
         connection_parameters = [dict(key=value, value=arguments['<parameter>'][index]) for
                                       index, value in enumerate(adapter['connection_parameters'])]
-        client.create_adapter(adapter, arguments['<array-name>'], connection_parameters)
+        client.create_array(adapter, arguments['<array-name>'], connection_parameters)
 
 
 def do_delete_array(arguments):
     with _internal_open(arguments) as client:
         [adapter] = [item for item in client.get_arrays() if
                      item['name'] == arguments['<array-name>']]
-        client.delete_adapter(adapter)
+        client.delete_array(adapter)
 
 
 def do_start(arguments):
@@ -240,6 +241,19 @@ def do_show_result(arguments):
         print tabulate(table, tablefmt='rst')
 
 
+def do_purge(arguments):
+    with _internal_open(arguments) as internal_client, _open(arguments) as client:
+        for key, value in client.get_recovery_plans().items():
+            internal_client.delete_recovery_plan(value)
+        for item in internal_client.get_protection_groups():
+            internal_client.delete_protection_group(item)
+        for array in internal_client.get_arrays():
+            for pool in array['pools']:
+                if pool['enabled']:
+                    internal_client.disable_array_pair(array, pool)
+            internal_client.delete_array(array)
+
+
 def parse_commandline_arguments(argv):
     from srm_client.__version__ import __version__
     return docopt.docopt(__doc__, argv=argv, version=__version__)
@@ -287,6 +301,8 @@ def srm(argv=sys.argv[1:]):
                     do_create_protection_group(arguments)
                 elif arguments['delete']:
                     do_delete_protection_group(arguments)
+            elif arguments['purge']:
+                do_purge(arguments)
         except SrmClientException, e:
             sys.stderr.write("ERROR: %s\n" % e.message)
             return 1
